summaryrefslogtreecommitdiffstats
path: root/build/jenkins-build.sh
diff options
context:
space:
mode:
authorTomasKulhanek <tomas.kulhanek@stfc.ac.uk>2018-12-07 11:16:04 +0000
committerTomasKulhanek <tomas.kulhanek@stfc.ac.uk>2018-12-07 11:16:04 +0000
commite1f923fb8827dcb5b9763403080e2947d7b36fca (patch)
tree6e51f609335d32326ca64122dc069edead871eed /build/jenkins-build.sh
parentdb76ce4375838e1e5bb3d51cf5b795e1798b7089 (diff)
downloadregularization-e1f923fb8827dcb5b9763403080e2947d7b36fca.tar.gz
regularization-e1f923fb8827dcb5b9763403080e2947d7b36fca.tar.bz2
regularization-e1f923fb8827dcb5b9763403080e2947d7b36fca.tar.xz
regularization-e1f923fb8827dcb5b9763403080e2947d7b36fca.zip
skip reason
Diffstat (limited to 'build/jenkins-build.sh')
-rwxr-xr-xbuild/jenkins-build.sh25
1 files changed, 21 insertions, 4 deletions
diff --git a/build/jenkins-build.sh b/build/jenkins-build.sh
index 67bb559..b74c38d 100755
--- a/build/jenkins-build.sh
+++ b/build/jenkins-build.sh
@@ -1,12 +1,29 @@
#!/usr/bin/env bash
# Script to builds source code in Jenkins environment
+module try-load conda
-module avail
-module load conda
-# it expects that git clone is done before this script launch
+# install miniconda if the module is not present
+if hash conda 2>/dev/null; then
+ echo using conda
+else
+ if [ ! -f Miniconda3-latest-Linux-x86_64.sh ]; then
+ wget -q https://repo.continuum.io/miniconda/Miniconda3-latest-Linux-x86_64.sh
+ chmod +x Miniconda3-latest-Linux-x86_64.sh
+ fi
+ ./Miniconda3-latest-Linux-x86_64.sh -u -b -p .
+ PATH=$PATH:./bin
+fi
+
+# presume that git clone is done before this script launch
# git clone https://github.com/vais-ral/CCPi-Regularisation-Toolkit
conda install -y conda-build
#export CIL_VERSION=0.10.2
-export CIL_VERSION=0.10.2
+if [[ -n ${CIL_VERSION} ]]
+then
+ echo Using defined version: $CIL_VERSION
+else
+ export CIL_VERSION=0.10.2
+ echo Defining version: $CIL_VERSION
+fi
#cd CCPi-Regularisation-Toolkit # already there by jenkins
conda build Wrappers/Python/conda-recipe